package com.aitrainer.api.controller

import com.aitrainer.api.model.Purchase
import com.aitrainer.api.repository.PurchaseRepository
import org.slf4j.LoggerFactory
import org.springframework.http.ResponseEntity
import org.springframework.web.bind.annotation.*
import javax.validation.Valid

@RestController
@RequestMapping("/api")
class PurchaseController(private val purchaseRepository: PurchaseRepository) {
    private val logger = LoggerFactory.getLogger(javaClass)

    @GetMapping("/purchase/customer/{id}")
    fun getAllByCustomerId(@PathVariable(value = "id") customerId: Long): ResponseEntity<List<Purchase>> {

        val purchaseList  = purchaseRepository.findByCustomerId(customerId)
        logger.info("Get all purchase by customerId")

        return if(purchaseList.isNotEmpty())
            ResponseEntity.ok().body(purchaseList) else
            ResponseEntity.notFound().build()
    }

    @PostMapping("/purchase")
    fun insertPurchase(@Valid @RequestBody purchase: Purchase): ResponseEntity<Purchase> {
        val newPurchase = purchaseRepository.save(purchase)
        logger.info("Create new purchase: $newPurchase")
        return ResponseEntity.ok().body(newPurchase)
    }
}